@@ -5,7 +5,7 @@ pub mod tools;
 
 mod real_test {
     use basic_dsp::*;
-    use tools::*;
+    use crate::tools::*;
 
     #[allow(dead_code)]
     fn real_add(a: &Vec<f32>, b: &Vec<f32>) -> Vec<f32> {
